<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label=" 选项内容 " prop="optioncontent">
        <el-input v-model="queryParams.optioncontent" placeholder="请输入 选项内容 " clearable
          @keyup.enter.native="handleQuery" />
      </el-form-item>
      <el-form-item label=" 归属机构 " prop="orgid">
        <el-input v-model="queryParams.orgid" placeholder="请输入 机构ID " clearable @keyup.enter.native="handleQuery" />
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button type="primary" plain icon="el-icon-plus" size="mini" @click="handleAdd"
          v-hasPermi="['smartor:svytopicoption:add']">新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="success" plain icon="el-icon-edit" size="mini" :disabled="single" @click="handleUpdate"
          v-hasPermi="['smartor:svytopicoption:edit']">修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="danger" plain icon="el-icon-delete" size="mini" :disabled="multiple" @click="handleDelete"
          v-hasPermi="['smartor:svytopicoption:remove']">删除</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="warning" plain icon="el-icon-download" size="mini" @click="handleExport"
          v-hasPermi="['smartor:svytopicoption:export']">导出</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="svytopicoptionList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label=" 题目类型 " width="150" align="center" prop="topictype" />
      <el-table-column label=" 选项内容 " width="200" align="center" prop="optioncontent" />
      <el-table-column label=" 提示 " width="200" align="center" prop="prompt" />
      <el-table-column label=" 分数 " width="55" align="center" prop="score" />
      <el-table-column label=" 验证规则 " width="250" align="center" prop="verifyrule" />
      <el-table-column label=" 是否存在明细 " width="150" align="center" prop="isexistdetail" />
      <el-table-column label=" 归属机构 " width="200" align="center" prop="orgid" />
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button size="mini" type="text" icon="el-icon-edit" @click="handleUpdate(scope.row)"
            v-hasPermi="['smartor:svytopicoption:edit']">修改</el-button>
          <el-button size="mini" type="text" icon="el-icon-delete" @click="handleDelete(scope.row)"
            v-hasPermi="['smartor:svytopicoption:remove']">删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination v-show="total > 0" :total="total" :page.sync="queryParams.pageNum" :limit.sync="queryParams.pageSize"
      @pagination="getList" />

    <!-- 添加或修改问卷问题选项对话框 -->
    <maintdlg ref="maint"/>
  </div>
</template>

<script>
import { listSvytopicoption, getSvytopicoption, delSvytopicoption, addSvytopicoption, updateSvytopicoption } from "@/api/smartor/svytopicoption";
import maintdlg from  "@/smartor/dataobject/dw_svytopicoption_maint.vue";

export default {
  name: "Svytopicoption",
  data() {
    return {
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 问卷问题选项表格数据
      svytopicoptionList: [],
       // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        topicid: null,
        svyid: null,
        topictype: null,
        optioncode: null,
        optioncontent: null,
        isexistdetail: null,
        detailismandatory: null,
        isexceptionitem: null,
        istrack: null,
        score: null,
        prompt: null,
        jump: null,
        parentoptionid: null,
        ismutex: null,
        verifyrule: null,
        sort: null,
        verificationtype: null,
        isrange: null,
        minrange: null,
        maxrange: null,
        rangelength: null,
        orgid: null,
        oldid: null,
        isupload: null,
        uploadTime: null
      },
    };
  },
  components:
  {
    maintdlg: maintdlg //()=>import("@/smartor/dataobject/dw_svytopicoption_maint")
  },
  created() {
     this.getList();
   },
  mounted() {
    
  },
  methods: {
    /** 查询问卷问题选项列表 */
    getList() {
      this.loading = true;
      listSvytopicoption(this.queryParams).then(response => {
        this.svytopicoptionList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.optionid)
      this.single = selection.length !== 1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.$refs["maint"].handleUpdate(null)
      return
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      const optionid = row.optionid || this.ids
      this.$refs["maint"].handleUpdate(optionid) 
      return 
    },
    
    /** 删除按钮操作 */
    handleDelete(row) {
      const optionids = row.optionid || this.ids;
      this.$modal.confirm('是否确认删除问卷问题选项编号为"' + optionids + '"的数据项？').then(function () {
        return delSvytopicoption(optionids);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => { });
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('smartor/svytopicoption/export', {
        ...this.queryParams
      }, `svytopicoption_${new Date().getTime()}.xlsx`)
    }
  }
};
</script>
